# UniversalApplicationAssembler

The Universal Application Assembler (UAA) is a totally configurable assembler that let's you target any ISA spefication by simply writing a config yaml file defining the characteristics of each instruction. The idea is of have an universal assembler that is trivial to port to any ISA.

## Documentation

Currently there is no documentation of this project. It will be added in the future.

## Examples

Currently there is also no public examples. Some of them will get released in the future implementing some custom architectures.
